Runtime

Struct Runtime 

pub struct Runtime { /* private fields */ }
See Runtime

Implementations

Source

impl Runtime

pub fn new() -> Result<Self>

Create Runtime.

Source

impl Runtime

pub fn poll_and_run(&self) -> Option<Duration>

Poll the runtime. Returns the next timeout.

pub fn block_on<F: Future>( &self, future: F, poll: impl Fn(Option<Duration>), ) -> F::Output

Block on the future till it completes. Users should enter the runtime before calling this function, and poll the runtime themselves.

Methods from Deref<Target = Runtime>

pub fn driver_type(&self) -> DriverType

The current driver type.

pub fn enter<T, F>(&self, f: F) -> T
where F: FnOnce() -> T,

Set this runtime as current runtime, and perform a function in the current scope.

pub unsafe fn spawn_unchecked<F>( &self, future: F, ) -> Task<<F as Future>::Output>
where F: Future,

Low level API to control the runtime.

Spawns a new asynchronous task, returning a Task for it.

Safety

Borrowed variables must outlive the future.

pub fn run(&self) -> bool

Low level API to control the runtime.

Run the scheduled tasks.

The return value indicates whether there are still tasks in the queue.

pub fn waker(&self) -> Waker

Low level API to control the runtime.

Create a waker that always notifies the runtime when woken.

pub fn opt_waker(&self) -> Arc<OptWaker>

Low level API to control the runtime.

Create an optimized waker that only notifies the runtime when woken from another thread, or when notify-always is enabled.

pub fn block_on<F>(&self, future: F) -> <F as Future>::Output
where F: Future,

Block on the future till it completes.

pub fn spawn<F>( &self, future: F, ) -> Task<Result<<F as Future>::Output, Box<dyn Any + Send>>>
where F: Future + 'static,

Spawns a new asynchronous task, returning a Task for it.

Spawning a task enables the task to execute concurrently to other tasks. There is no guarantee that a spawned task will execute to completion.

pub fn spawn_blocking<T>( &self, f: impl FnOnce() -> T + Send + 'static, ) -> Task<Result<T, Box<dyn Any + Send>>>
where T: Send + 'static,

Spawns a blocking task in a new thread, and wait for it.

The task will not be cancelled even if the future is dropped.

pub fn attach(&self, fd: i32) -> Result<(), Error>

Attach a raw file descriptor/handle/socket to the runtime.

You only need this when authoring your own high-level APIs. High-level resources in this crate are attached automatically.

pub fn current_timeout(&self) -> Option<Duration>

Low level API to control the runtime.

Get the timeout value to be passed to Proactor::poll.

pub fn poll(&self)

Low level API to control the runtime.

Poll the inner proactor. It is equal to calling Runtime::poll_with with Runtime::current_timeout.

pub fn poll_with(&self, timeout: Option<Duration>)

Low level API to control the runtime.

Poll the inner proactor with a custom timeout.

pub fn register_personality(&self) -> Result<u16, Error>

Register the personality for the runtime.

This is only supported on io-uring driver, and will return an Unsupported io error on all other drivers.

The returned personality can be used with FutureExt::with_personality if the future-combinator feature is turned on.

pub fn unregister_personality(&self, personality: u16) -> Result<(), Error>

Unregister the given personality for the runtime.

This is only supported on io-uring driver, and will return an Unsupported io error on all other drivers.