Runtime

Struct Runtime 

pub struct Runtime { /* private fields */ }
See Runtime

Implementations

Source

impl Runtime

pub fn new() -> Result<Self>

Create Runtime.

Source

impl Runtime

pub fn poll_and_run(&self) -> Option<Duration>

Poll the runtime. Returns the next timeout.

pub fn block_on<F: Future>( &self, future: F, poll: impl Fn(Option<Duration>), ) -> F::Output

Block on the future till it completes. Users should enter the runtime before calling this function, and poll the runtime themselves.

Methods from Deref<Target = Runtime>

pub fn driver_type(&self) -> DriverType

The current driver type.

pub fn enter<T, F>(&self, f: F) -> T
where F: FnOnce() -> T,

Set this runtime as current runtime, and perform a function in the current scope.

pub unsafe fn spawn_unchecked<F>( &self, future: F, ) -> Task<<F as Future>::Output>
where F: Future,

Spawns a new asynchronous task, returning a Task for it.

Safety

The caller should ensure the captured lifetime long enough.

pub fn run(&self) -> bool

Low level API to control the runtime.

Run the scheduled tasks.

The return value indicates whether there are still tasks in the queue.

pub fn block_on<F>(&self, future: F) -> <F as Future>::Output
where F: Future,

Block on the future till it completes.

pub fn spawn<F>( &self, future: F, ) -> Task<Result<<F as Future>::Output, Box<dyn Any + Send>>>
where F: Future + 'static,

Spawns a new asynchronous task, returning a Task for it.

Spawning a task enables the task to execute concurrently to other tasks. There is no guarantee that a spawned task will execute to completion.

pub fn spawn_blocking<T>( &self, f: impl FnOnce() -> T + Send + 'static, ) -> Task<Result<T, Box<dyn Any + Send>>>
where T: Send + 'static,

Spawns a blocking task in a new thread, and wait for it.

The task will not be cancelled even if the future is dropped.

pub fn attach(&self, fd: i32) -> Result<(), Error>

Attach a raw file descriptor/handle/socket to the runtime.

You only need this when authoring your own high-level APIs. High-level resources in this crate are attached automatically.

pub fn submit<T>(&self, op: T) -> impl Future<Output = BufResult<usize, T>>
where T: OpCode + 'static,

👎Deprecated: use compio::runtime::submit instead

Submit an operation to the runtime.

You only need this when authoring your own OpCode.

It is safe to send the returned future to another runtime and poll it, but the exact behavior is not guaranteed, e.g. it may return pending forever or else.

pub fn submit_with_flags<T>( &self, op: T, ) -> impl Future<Output = (BufResult<usize, T>, u32)>
where T: OpCode + 'static,

👎Deprecated: use compio::runtime::submit_with_flags instead

Submit an operation to the runtime.

The difference between Runtime::submit is this method will return the flags

You only need this when authoring your own OpCode.

It is safe to send the returned future to another runtime and poll it, but the exact behavior is not guaranteed, e.g. it may return pending forever or else.

pub fn current_timeout(&self) -> Option<Duration>

Low level API to control the runtime.

Get the timeout value to be passed to Proactor::poll.

pub fn poll(&self)

Low level API to control the runtime.

Poll the inner proactor. It is equal to calling Runtime::poll_with with Runtime::current_timeout.

pub fn poll_with(&self, timeout: Option<Duration>)

Low level API to control the runtime.

Poll the inner proactor with a custom timeout.